"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var canvas_kit_react_common_1 = require("@workday/canvas-kit-react-common");
var useListModel_1 = require("../list/useListModel");
exports.cursorEventMap = canvas_kit_react_common_1.createEventMap()({
    guards: __assign(__assign({}, useListModel_1.listEventMap.guards), { shouldGoTo: 'goTo' }),
    callbacks: __assign(__assign({}, useListModel_1.listEventMap.callbacks), { onGoTo: 'goTo' }),
});
var getFirst = function (items) {
    return items[0];
};
var getLast = function (items) {
    return items[items.length - 1];
};
exports.getItem = function (id, items) {
    var item = id ? items.find(function (item) { return item.id === id; }) : getFirst(items);
    canvas_kit_react_common_1.assert(item, "Item not found: " + id);
    return item;
};
var getOffsetItem = function (offset) { return function (id, items) {
    var _a;
    var item = exports.getItem(id, items);
    var currentIndex = items.findIndex(function (_a) {
        var id = _a.id;
        return item.id === id;
    });
    var nextIndex = currentIndex + offset;
    if (nextIndex < 0) {
        nextIndex = items.length - 1;
    }
    else if (nextIndex >= items.length) {
        nextIndex = 0;
    }
    var disabledAttribute = (_a = items[nextIndex].ref.current) === null || _a === void 0 ? void 0 : _a.getAttribute('disabled');
    if (disabledAttribute !== null || disabledAttribute === 'false') {
        return getOffsetItem(offset)(items[nextIndex].id, items);
    }
    return items[nextIndex];
}; };
var getNext = getOffsetItem(1);
var getPrevious = getOffsetItem(-1);
exports.useCursorModel = function (config) {
    if (config === void 0) { config = {}; }
    var orientation = react_1.default.useState(config.orientation || 'vertical')[0];
    var _a = react_1.default.useState(''), cursorId = _a[0], setCursorId = _a[1];
    var initialCurrentRef = react_1.default.useRef('');
    var list = useListModel_1.useListModel(__assign(__assign({}, config), { onRegisterItem: function (_a) {
            var data = _a.data, state = _a.state;
            var _b;
            if (!initialCurrentRef.current) {
                initialCurrentRef.current = data.item.id;
                setCursorId(initialCurrentRef.current);
            }
            (_b = config.onRegisterItem) === null || _b === void 0 ? void 0 : _b.call(config, { data: data, state: state });
        } }));
    var state = __assign(__assign({}, list.state), { orientation: orientation, cursorId: cursorId });
    var events = canvas_kit_react_common_1.useEventMap(exports.cursorEventMap, state, config, __assign(__assign({}, list.events), { goTo: function (_a) {
            var id = _a.id;
            setCursorId(id);
        },
        next: function () {
            setCursorId(getNext(state.cursorId, state.items).id);
        },
        previous: function () {
            setCursorId(getPrevious(state.cursorId, state.items).id);
        },
        first: function () {
            setCursorId(getFirst(state.items).id);
        },
        last: function () {
            setCursorId(getLast(state.items).id);
        } }));
    return { state: state, events: events };
};
