import { Model, ToModelConfig } from '@workday/canvas-kit-react-common';
import { CursorState, CursorEvents, BaseCursorModelConfig, Orientation } from './cursor/useCursorModel';
import { Item, ListEvents, ListState } from './list/useListModel';
export declare type TabsState = CursorState & {
    activeTab: string;
    panels: Item[];
    panelIndexRef: ListState['indexRef'];
};
export declare type TabsEvents = CursorEvents & {
    activate(data: {
        tab: string;
    }): void;
    registerPanel: ListEvents['registerItem'];
    unregisterPanel: ListEvents['unregisterItem'];
};
export declare type TabsModel = Model<TabsState, TabsEvents>;
export declare const tabEventMap: {
    guards: {
        shouldActivate: "activate";
        shouldGoTo: "goTo";
        shouldRegisterItem: "registerItem";
        shouldUnregisterItem: "unregisterItem";
    };
    callbacks: {
        onActivate: "activate";
        onGoTo: "goTo";
        onRegisterItem: "registerItem";
        onUnregisterItem: "unregisterItem";
    };
};
export declare type BaseTabsModelConfig = Omit<BaseCursorModelConfig, 'orientation'> & {
    id?: string;
    initialTab?: string;
    orientation?: Orientation;
};
export declare type TabsModelConfig = BaseTabsModelConfig & Partial<ToModelConfig<TabsState, TabsEvents, typeof tabEventMap>>;
export declare const useTabsModel: (config?: TabsModelConfig) => Model<TabsState, TabsEvents>;
//# sourceMappingURL=useTabsModel.d.ts.map